Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(289)

Unified Diff: net/base/cookie_options.h

Issue 4630001: Implement Origin cookies. Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/base/cookie_monster_unittest.cc ('k') | net/http/http_request_headers.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/cookie_options.h
===================================================================
--- net/base/cookie_options.h (revision 65294)
+++ net/base/cookie_options.h (working copy)
@@ -12,12 +12,13 @@
class CookieOptions {
public:
// Default is to exclude httponly, which means:
// - reading operations will not return httponly cookies.
// - writing operations will not write httponly cookies.
CookieOptions()
: exclude_httponly_(true),
- force_session_(false) {
+ force_session_(false),
+ read_origin_(false) {
}
void set_exclude_httponly() { exclude_httponly_ = true; }
@@ -28,9 +29,14 @@
void set_force_session() { force_session_ = true; }
bool force_session() const { return force_session_; }
+ void set_read_origin(bool flag) { read_origin_ = flag; }
+ bool read_origin() const { return read_origin_; }
+
private:
+ // TODO(abarth): These member variable names should be nouns and not verbs.
bool exclude_httponly_;
bool force_session_;
+ bool read_origin_;
};
} // namespace net
« no previous file with comments | « net/base/cookie_monster_unittest.cc ('k') | net/http/http_request_headers.h » ('j') | no next file with comments »
@@ -12,12 +12,13 @@
class CookieOptions {
public:
- // Default is to exclude httponly, which means:
- // - reading operations will not return httponly cookies.
+ // Default is for
+ // - reading operations will not return httponly or origin cookies.
// - writing operations will not write httponly cookies.
CookieOptions()

Powered by Google App Engine
This is Rietveld 408576698